@@ -6,7 +6,6 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
   # Additional functions (subroutines)
 
   # Determine file extension
-
   FileExt <- function(x) {
     ext <- tolower(tail(unlist(strsplit(basename(x), "\\."))[-1], 1))
     if (length(ext) == 0L)
@@ -16,7 +15,8 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
 
 
   # Main program
-
+  
+  # Initialize file filters
   all.filters <- list(bmp  = "Windows Bitmap Files",
                       csv  = "Text Files",
                       dat  = "Text Files",
@@ -37,23 +37,27 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
                       txt  = "Text Files"
                   )
 
+  # Process connection and return
   if (!is.null(file)) {
     if (inherits(file, "connection"))
-      file <- summary.connection(file)$description
-    dir <- dirname(file)
-    ext <- FileExt(file)
-    nam <- sub(paste(".", ext, "$", sep=""), "", basename(file))
-    typ <- all.filters[[ext]]
-    f <- list(path=file, dir=dir, name=nam, ext=ext, type=typ)
-    Data("default.dir", dir)
-    return(f)
+      val <- summary.connection(file)$description
+    else
+      val <- file
+    ext <- FileExt(val)
+    attr(val, "directory") <- dirname(val)
+    attr(val, "extension") <- ext
+    attr(val, "name") <- sub(paste(".", ext, "$", sep=""), "", basename(val))
+    attr(val, "type") <- all.filters[[ext]]
+    Data("default.dir", attr(val, "directory"))
+    return(val)
   }
-
+  
+  # Establish initial directory
   if (is.null(initialdir))
     initialdir <- Data("default.dir")
-
+  
+  # Build filters
   filters <- matrix(nrow=0, ncol=2)
-
   if (!is.null(exts)) {
     for (ext in tolower(exts)) {
       typ <- all.filters[[ext]]
@@ -62,34 +66,32 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
       filters <- rbind(filters, c(typ, paste(".", ext, sep="")))
     }
   }
-
   filters   <- rbind(filters, c("All files", "*"))
   filters[] <- paste("{", filters, "}", sep="")
   filters   <- apply(filters, 1, paste, collapse=" ")
   filters   <- paste(paste("{", filters, "}", sep=""), collapse=" ")
 
+  # Build arguments
   if (tolower(substr(cmd, 1, 4)) == "open")
     args <- list("tk_getOpenFile", title=win.title, multiple=multi)
   else
     args <- list("tk_getSaveFile", title=win.title)
-
   if (!is.null(parent))
     args[["parent"]] <- parent
-
   if (!is.null(defaultextension))
     args <- c(args, defaultextension=defaultextension)
   if (!is.null(initialdir))
     args <- c(args, initialdir=initialdir)
   if (!is.null(initialfile))
     args <- c(args, initialfile=initialfile)
-
   args <- c(args, filetypes=filters)
 
+  # Open file dialog gui
   res <- tclvalue(do.call(tcl, args))
-
   if (!nzchar(res))
     return()
-
+  
+  # Account for mutiple files
   if (multi) {
     ans <- character()
     pat <- "([^{])*\\{([^}]*)\\}(.*)"
@@ -102,25 +104,28 @@ GetFile <- function(cmd="Open", file=NULL, exts=NULL, initialdir=NULL,
   } else {
     ans <- res
   }
-
+  
+  # Package results
   n <- length(ans)
   if (n > 1)
     f <- list()
+  
   for (i in seq(along=ans)) {
-    pth <- ans[i]
-    dir <- dirname(pth)
-    ext <- FileExt(pth)
-    nam <- sub(paste(".", ext, "$", sep=""), "", basename(pth))
-    typ <- all.filters[[ext]]
-    val <- list(path=pth, dir=dir, name=nam, ext=ext, type=typ)
+    val <- ans[i]
+    ext <- FileExt(val)
+    attr(val, "directory") <- dirname(val)
+    attr(val, "extension") <- ext
+    attr(val, "name") <- sub(paste(".", ext, "$", sep=""), "", basename(val))
+    attr(val, "type") <- all.filters[[ext]]
     if (n > 1)
       f[[i]] <- val
     else
       f <- val
   }
-
+  
+  # Set default directory
   if (!is.null(f))
-    Data("default.dir", dir)
+    Data("default.dir", attr(val, "directory"))
 
   f
 }
